API docs for “spamfighter.interfaces”

# Module s.interfaces

Part of spamfighter View Source

Базовые интерфейсы проекта.

Class | IDomain | Домен - единица настроек, привязки локальных элементов
Class | IPartnerAuthorizer | Модуль авторизации партнеров. Способ авторизации не задается интерфейсом, но
Class | IPartnerRegistrator | Модуль регистрации партнеров с использованием логинов и паролей.
Class | IPartner | Партнер - единица авторизации относительно API веб-сервиса СпамоБорца.
Class | IAttribute | Атрибуты характеризуют отправителя и получателя сообщений, они могут нести разную информацию.
Class | IAttributeDomain | Домент (тип атрибута).
Class | IMessageDomain | Список доменов атрибутов, которые должны быть у сообщения.
Class | IMessage | Сообщение - основная единица обработки для Спамоборца.
Class | ITaggedMessage | Сообщение с прицепленными к нему тэгами.
Class | IMessageAnalyzer | Некоторый черный ящик анализа сообщений. Получает на вход
Class | IMessageFirewall | Маркерный интерфейс файрвола.
Class | IModel | Интерфейс модели анализа сообщений.
Class | IDomainBindable | Интерфейс объекта, который при помещении в домен должен
Class | IStorage | Базовый интерфейс хранилища.
Class | IPersistentStorage | Маркерный интерфейс хранилища, которое гарантирует
Class | IUnreliableStorage | Маркерный интерфейс хранилища, которое не гарантирует
Class | IExpirableStorage | Ненадежное хранилище, в котором данные имеют ограниченный срок жизни. Хранилище
Class | ILogEntry | Отдельная запись в логе сообщений.
Class | IMessageLog | Лог сообщений, проходящих через сервер.